import { html, css, LitElement } from "lit";
import { property, customElement } from "lit/decorators.js";

import "@components/EveLink";

@customElement("arx-breadcrumbs-item")
export class BreadcrumbsItem extends LitElement {
  @property() text = "";
  @property() href?: string;
  @property() index = 0;

  static override styles = [
    css`
      li {
        display: inline-block;
        margin-right: 0.5rem;
      }

      .separator {
        margin-inline: 0.5rem;
        color: var(--secondary);
        user-select: none;
      }

      .link {
        color: var(--accent);
        text-decoration: none;
        transition: text-decoration 0.2s;
      }

      .secondary {
        color: var(--secondary);
      }
    `,
  ];

  override render() {
    return html`
      <li>
        ${this.index > 0
          ? html`<span class="separator" aria-hidden="true">/</span>`
          : ""}
        ${this.href
          ? html`<arx-eve-link class="link" href=${this.href}
              >${this.text}</arx-eve-link
            >`
          : html`<span class="secondary">${this.text}</span>`}
      </li>
    `;
  }
}
