import { css, html, LitElement } from "lit";
import { customElement, property } from "lit/decorators.js";

@customElement("arx-eve-link")
export class EveLink extends LitElement {
  @property({ type: String }) href = "#";
  @property({ type: String }) target = "";
  @property({ type: String }) rel = "";

  get hrefValue() {
    let href = this.href;
    if (href.startsWith("javascript:")) return href;
    if (href.startsWith("eve://")) href = href.replace("eve://", "#");
    if (href.startsWith("/")) href = href.replace("/", "#");
    if (!href.startsWith("#")) href = `#${href}`;
    return href;
  }

  static override styles = css`
    a {
      part: link;
    }
  `;

  override render() {
    return html`
      <a
        part="link"
        .href=${this.hrefValue}
        .target=${this.target}
        .rel=${this.rel}
      >
        <slot></slot>
      </a>
    `;
  }
}
