import type { NDKUserProfile } from '@nostr-dev-kit/ndk';
import { css, html, LitElement } from 'lit-element';
import { customElement, property } from 'lit/decorators.js';
type AvatarSize = 'short' | 'medium' | 'large' | 'huge';

@customElement('arx-nostr-avatar')
export class ArxNostrAvatar extends LitElement {
  @property({ type: Object }) profile!: NDKUserProfile;
  @property({ type: String }) size!: AvatarSize;

  static override styles = [
    css`
    img {
      border-radius: 50%;
      width: var(--avatar-size);
      height: var(--avatar-size);
    }
    .short-avatar {
      --avatar-size: 2rem;
    }
    .medium-avatar {
      --avatar-size: 3rem;
    }
    .large-avatar {
      --avatar-size: 4rem;
    }
    .huge-avatar {
      --avatar-size: 5rem;
    }
  `,
  ];

  override render() {
    return html`
      <img
        class=${this.size}-avatar
        src=${this.profile.image || '/default-avatar.png'}
        alt=${this.profile.name || this.profile.displayName || ''}
        @error=${this.handleError}
      />
    `;
  }

  handleError(event: Event) {
    event.preventDefault();
    (event.target as HTMLImageElement).src = '/default-avatar.png';
  }
}
