import { html, css, LitElement } from "lit";
import { property, customElement } from "lit/decorators.js";

import "@components/EveLink";

@customElement("arx-phora-button")
export class PhoraButton extends LitElement {
  @property({ type: String }) href = "";
  @property({ type: String }) target = "";
  @property({ type: String }) rel = "";
  @property({ type: Boolean }) disabled = false;

  get hrefValue() {
    if (!this.href || this.disabled) return "javascript:void(0)";
    return this.href;
  }

  static override styles = [
    css`
      arx-eve-link::part(link) {
        display: inline-flex;
        align-items: center;
        justify-content: center;
        background: var(--accent);
        color: white;
        border: none;
        text-decoration: none;
        padding: 0.75rem 0.75rem;
        border-radius: 0.25rem;
        text-decoration: none;
        font-size: 0.9rem;
        font-weight: 500;
        line-height: 1.2;
        cursor: pointer;
        transition: all 0.2s ease-in-out;
        box-shadow: var(--shadow-sm);
        gap: 5px;
      }

      arx-eve-link:hover {
        transform: translateY(-1px);
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.15);
        background: color-mix(in oklch, var(--accent), black 15%);
      }

      arx-eve-link:focus {
        outline: none;
        box-shadow: var(--shadow-md);
      }

      arx-eve-link:active {
        transform: translateY(0);
        box-shadow: var(--shadow-md);
      }

      arx-eve-link.disabled {
        opacity: 0.6;
        cursor: not-allowed;
      }
    `,
  ];

  override render() {
    return html`
      <arx-eve-link
        .href=${this.hrefValue}
        .target=${this.target}
        .rel=${this.rel}
        class="${this.disabled ? "disabled" : ""}"
      >
        <slot></slot>
      </arx-eve-link>
    `;
  }
}
