import { html, css, LitElement } from "lit";
import { property, customElement } from "lit/decorators.js";

import "@components/EveLink";

@customElement("arx-phora-forum-topic")
export class PhoraForumTopic extends LitElement {
  static override styles = [
    css`
      .topic {
        display: grid;
        grid-template-columns: 3fr 1fr;
        padding: 1.75rem;
        border-radius: 12px;
        margin-bottom: 1rem;
        box-shadow: var(--shadow-md);
        transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1);
      }

      .topic:hover {
        transform: translateY(-2px);
        box-shadow: var(--shadow-lg);
      }

      .topic-icon {
        inline-size: 40px;
        block-size: 40px;
        background: var(--accent);
        border-radius: 10px;
        flex-shrink: 0;
        position: relative;
        overflow: hidden;
        box-shadow: var(--shadow-sm);
      }

      .topic-icon::after {
        content: "";
        position: absolute;
        inset: 0;
        background: linear-gradient(
          45deg,
          transparent,
          oklch(from var(--accent) l c h / 0.2)
        );
      }

      .topic-info {
        display: flex;
        gap: 1.5rem;
        align-items: flex-start;
      }

      .topic-details {
        flex: 1;
      }

      arx-eve-link::part(link) {
        display: inline-block;
        margin-bottom: 0.875rem;
        font-size: 1.2rem;
        font-weight: 600;
        letter-spacing: -0.01em;
        text-decoration: none;
        color: var(--primary);
        transition: all 0.2s ease;
        &:hover {
          color: var(--secondary);
          transform: translateX(4px);
        }
      }

      .topic-details p {
        margin: 0;
        font-size: 0.975rem;
        line-height: 1.6;
        color: var(--secondary);
      }

      .new-status {
        position: relative;
        color: var(--accent);
      }

      .new-status::after {
        content: "New";
        position: absolute;
        top: -8px;
        right: -40px;
        font-size: 0.75rem;
        font-weight: 700;
        text-transform: uppercase;
        background: var(--accent);
        color: var(--light);
        padding: 2px 8px;
        border-radius: 12px;
        box-shadow: var(--shadow-sm);
      }

      .hot-status {
        color: var(--error);
      }

      .hot-status::before {
        content: "🔥";
        margin-right: 0.5rem;
      }

      .stats-container {
        display: flex;
        flex-direction: column;
        gap: 1rem;
        padding-left: 1.5rem;
        border-left: 2px solid var(--border);
      }

      .post-count {
        display: flex;
        align-items: center;
        gap: 0.625rem;
        color: var(--secondary);
        font-weight: 500;
      }

      .post-count :deep(iconify-icon) {
        font-size: 1.375rem;
        color: var(--accent);
      }

      .last-post-section {
        background: oklch(from var(--primary) 98% calc(c * 0.2) h);
        padding: 0.875rem;
        border-radius: 8px;
        box-shadow: var(--shadow-sm);
      }

      .last-post-section > div:first-of-type {
        font-size: 0.875rem;
        font-weight: 500;
        color: var(--secondary);
        margin-bottom: 0.5rem;
      }

      .last-post-info {
        color: var(--secondary);
        font-size: 0.875rem;
        margin-top: 0.625rem;
        padding-top: 0.625rem;
        border-top: 1px solid var(--border);
      }

      @media (max-width: 968px) {
        .topic {
          grid-template-columns: 1fr;
          gap: 1.5rem;
          padding: 1.25rem;
        }

        .stats-container {
          padding-left: 0;
          border-left: none;
          padding-top: 1rem;
          border-top: 2px solid var(--border);
        }
      }
    `,
  ];

  @property({ type: String }) override id = "";
  @property({ type: String }) override title = "";
  @property({ type: String }) description = "";
  @property({ type: Number }) posts = 0;
  @property({ type: String }) lastPostBy = "";
  @property({ type: String }) lastPostTime = "";
  @property({ type: Boolean }) isNew = false;
  @property({ type: Boolean }) isHot = false;

  get status() {
    if (this.isNew) return "new-status";
    if (this.isHot) return "hot-status";
    return "";
  }

  override render() {
    return html`
      <div class="topic">
        <div class="topic-info">
          <div class="topic-icon"></div>
          <div class="topic-details">
            <arx-eve-link
              class="${this.status}"
              href="/phora/topics/${this.id}"
            >
              ${this.title}
            </arx-eve-link>
            <p>${this.description}</p>
          </div>
        </div>
        <div class="stats-container">
          <div class="post-count">
            <iconify-icon icon="material-symbols:forum-rounded"></iconify-icon>
            <span>${this.posts.toLocaleString()} posts</span>
          </div>
          <div class="last-post-section">
            <div>Latest activity</div>
            <arx-nostr-profile npub="${this.lastPostBy}"></arx-nostr-profile>
            <div class="last-post-info">${this.lastPostTime}</div>
          </div>
        </div>
      </div>
    `;
  }
}
