import { html, css, LitElement } from 'lit';
import { property, customElement, state } from 'lit/decorators.js';
import type { NDKUserProfile } from '@nostr-dev-kit/ndk';
import { getProfile } from '@utils/profileUtils';
import firstLine from '@utils/firstLine';

@customElement('arx-nostr-large-profile')
export class LargeProfile extends LitElement {
  @property() profile!: NDKUserProfile;
  @property() npub = '';

  @state()
  private displayName = '';

  @state()
  private profileUrl = '';

  @state()
  private about = '';

  static override styles = [
    css`
      a {
        color: var(--primary);
        text-decoration: none;
        display: inline-flex;
        align-items: center;
        gap: 0.5rem;
      }

      .bio {
        white-space: pre-line;
        font-size: 0.9rem;
        color: var(--primary);
        margin: 0.5rem 0;
      }
    `,
  ];

  override firstUpdated() {
    const { displayName, profileUrl } = getProfile({
      profile: this.profile,
      npub: this.npub,
    });
    this.displayName = displayName;
    this.profileUrl = profileUrl;
    this.about = firstLine(this.profile.about);
  }

  override render() {
    return html`
      <router-link to=${this.profileUrl}>
        <arx-nostr-avatar .profile=${this.profile} size="large"></arx-nostr-avatar>
        <div>
          <h3>${this.displayName}</h3>
          <div class="bio">${this.about}</div>
        </div>
      </router-link>
    `;
  }
}
