import { html, css, LitElement } from "lit";
import { property, customElement, state } from "lit/decorators.js";
import type { NDKUserProfile } from "@nostr-dev-kit/ndk";
import { getProfile } from "@utils/profileUtils";
import firstLine from "@utils/firstLine";

import "@components/EveLink";

@customElement("arx-nostr-medium-profile")
export class MediumProfile extends LitElement {
  @property() profile!: NDKUserProfile;
  @property() npub = "";

  @state()
  private displayName = "";

  @state()
  private profileUrl = "";

  @state()
  private truncatedAbout = "";

  static override styles = [
    css`
      arx-eve-link::part(link) {
        color: var(--primary);
        text-decoration: none;
        display: inline-flex;
        align-items: center;
        gap: 0.5rem;
      }
    `,
  ];

  override firstUpdated() {
    const { displayName, profileUrl } = getProfile({
      profile: this.profile,
      npub: this.npub,
    });
    this.displayName = displayName;
    this.profileUrl = profileUrl;
    this.truncatedAbout = this.getTruncatedAbout();
  }

  getTruncatedAbout() {
    const about = firstLine(this.profile.about);
    return about?.length > 80 ? `${about.substring(0, 80)}...` : about;
  }

  override render() {
    return html`
      <arx-eve-link href=${this.profileUrl}>
        <arx-nostr-avatar
          .profile=${this.profile}
          size="medium"
        ></arx-nostr-avatar>
        <div>
          <div>${this.displayName}</div>
          <div class="bio">${this.truncatedAbout}</div>
        </div>
      </arx-eve-link>
    `;
  }
}
