import { html, css, LitElement } from "lit";
import { property, customElement, state } from "lit/decorators.js";
import type { NDKUserProfile } from "@nostr-dev-kit/ndk";
import { getProfile } from "@utils/profileUtils";

import "@components/EveLink";

@customElement("arx-nostr-short-profile")
export class ShortProfile extends LitElement {
  @property() profile!: NDKUserProfile;
  @property() npub = "";

  @state()
  private displayName = "";

  @state()
  private profileUrl = "";

  static override styles = [
    css`
      arx-eve-link::part(link) {
        color: var(--primary);
        text-decoration: none;
        display: inline-flex;
        align-items: center;
        gap: 0.5rem;
      }
    `,
  ];

  protected override firstUpdated(): void {
    const { displayName, profileUrl } = getProfile({
      profile: this.profile,
      npub: this.npub,
    });
    this.displayName = displayName;
    this.profileUrl = profileUrl;
  }

  override render() {
    return html`
      <arx-eve-link href=${this.profileUrl}>
        <arx-nostr-avatar
          .profile=${this.profile}
          size="short"
        ></arx-nostr-avatar>
        <span>${this.displayName}</span>
      </arx-eve-link>
    `;
  }
}
