import { app, shell, BrowserWindow, ipcMain } from "electron";
import { optimizer, is } from "@electron-toolkit/utils";
import { RelayManager } from "./relayManager";
import path from "node:path";
import fs from "node:fs";
import os from "node:os";

const relay = new RelayManager();

ipcMain.handle("relay:writeSeed", async (_, ...args: any) => {
  if (!args[0]) throw new Error("No seed provided");
  const seed = args[0] as string;
  let configPath: string;
  if (process.platform === "darwin") {
    configPath = path.join(app.getPath("userData"), "arx", "Eve");
  } else {
    configPath = path.join(os.homedir(), ".config", "arx", "Eve");
  }

  const seedPath = path.join(configPath, "ccn.seed");
  fs.mkdirSync(configPath, { recursive: true });
  fs.writeFileSync(seedPath, seed);
});

ipcMain.handle("relay:start", (_, ...args: any) => {
  if (!args[0]) throw new Error("No encryption key provided");
  const encryptionKey = args[0] as string;
  return relay.start(encryptionKey);
});

ipcMain.handle("relay:stop", () => {
  return relay.stop();
});

ipcMain.handle("relay:status", () => {
  return {
    running: relay.isRunning,
    pid: relay.pid,
    logs: relay.getLogs(),
  };
});

ipcMain.handle("relay:getLogs", () => {
  return relay.getLogs();
});

function createWindow(): void {
  const mainWindow = new BrowserWindow({
    width: 1024,
    height: 768,
    show: false,
    autoHideMenuBar: true,
    webPreferences: {
      preload: path.join(__dirname, "../preload/preload.mjs"),
      sandbox: false,
    },
  });

  mainWindow.on("ready-to-show", () => {
    mainWindow.show();
  });

  mainWindow.webContents.setWindowOpenHandler((details) => {
    shell.openExternal(details.url);
    return { action: "deny" };
  });

  if (is.dev && process.env["ELECTRON_RENDERER_URL"])
    mainWindow.loadURL(process.env["ELECTRON_RENDERER_URL"]);
  else mainWindow.loadFile(path.join(__dirname, "../renderer/index.html"));
}

app.whenReady().then(() => {
  app.on("browser-window-created", (_, window) => {
    optimizer.watchWindowShortcuts(window);
  });

  createWindow();
});

app.on("window-all-closed", () => {
  app.quit();
});
