import { html, css, LitElement } from "lit";
import { customElement, property } from "lit/decorators.js";
import type { RouteParams } from "./router";

import "@components/EveLink";

@customElement("arx-404-page")
export class FourOhFourPage extends LitElement {
  @property({ type: Object })
  params: RouteParams = {};

  @property({ type: String })
  path = "";

  @property({ type: Boolean })
  canGoBack = false;

  static override styles = [
    css`
      .not-found {
        display: flex;
        align-items: center;
        justify-content: center;
        font-family: "Inter", sans-serif;
        padding: 1rem;
      }

      .content {
        max-width: 600px;
        text-align: center;
      }

      .error-container h1 {
        margin: 0;
      }

      .error-container h1 * {
        position: relative;
        margin: 0 -20px;
      }

      .spinning-gear {
        animation: spin 5s linear infinite;
      }

      @keyframes spin {
        from {
          transform: rotate(0deg);
        }
        to {
          transform: rotate(360deg);
        }
      }

      .path-container {
        background: rgba(255, 255, 255, 0.5);
        backdrop-filter: blur(10px);
        border: 1px solid rgba(255, 255, 255, 0.6);
        box-shadow: 0 8px 32px rgba(0, 0, 0, 0.2);
        margin-bottom: 2rem;
        padding: 1rem;
        backdrop-filter: blur(10px);
      }

      .path-text {
        color: var(--secondary);
        margin: 0 0 0.5rem 0;
        font-size: 0.9rem;
      }

      .path {
        font-family: "JetBrains Mono", monospace;
        color: var(--primary);
        word-break: break-all;
        font-size: 1.1rem;
        padding: 0.5rem;
        background: rgba(0, 0, 0, 0.2);
        border-radius: 4px;
        display: inline-block;
        max-width: 100%;
      }

      h1 {
        font-size: 8rem;
        font-weight: 800;
      }

      .message-text {
        display: flex;
        flex-direction: column;
        align-items: center;
        gap: 0.75rem;
      }

      .message-text .inline-icon {
        font-size: 1.25rem;
        flex-shrink: 0;
      }

      .status {
        font-size: 1.25rem;
        color: #94a3b8;
        margin: 1rem 0;
      }

      .sub-text {
        color: #64748b;
        display: flex;
        align-items: center;
        justify-content: center;
        gap: 0.5rem;
        margin-bottom: 2rem;
      }

      .inline-icon {
        font-size: 1.25rem;
      }

      .actions {
        display: flex;
        gap: 1rem;
        justify-content: center;
        flex-wrap: wrap;
      }

      .primary-button {
        display: flex;
        align-items: center;
        gap: 0.5rem;
        padding: 0.75rem 1.5rem;
        border-radius: 8px;
        font-weight: 600;
        transition: all 0.3s ease;
        text-decoration: none;
        background: var(--accent);
        color: white;

        &:hover {
          background: var(--secondary);
          transform: translateY(-2px);
        }
      }

      arx-eve-link::part(link) {
        color: white;
        text-decoration: none;
      }
    `,
  ];

  override render() {
    return html`
      <div class="not-found">
        <div class="content">
          <div class="error-container">
            <h1>
              <span class="four">4</span>
              <iconify-icon
                icon="fluent-emoji:gear"
                class="spinning-gear"
              ></iconify-icon>
              <span class="four">4</span>
            </h1>
          </div>
          <div class="path-container">
            <div class="path-text">Path:</div>
            <div class="path">${this.path}</div>
          </div>
          <div class="message-text">
            <div class="status">Page not found.</div>
            <div class="sub-text">
              The page you are looking for does not exist.
            </div>
          </div>
          <div class="actions">
            <a
              href="javascript:void(0)"
              @click="${() =>
                this.dispatchEvent(
                  new CustomEvent("go-back", {
                    bubbles: true,
                    composed: true,
                  })
                )}"
              class="primary-button"
            >
              <iconify-icon icon="material-symbols:arrow-back"></iconify-icon>
              Go back
            </a>
            <arx-eve-link href="home" class="primary-button">
              <iconify-icon icon="material-symbols:home"></iconify-icon>
              Home
            </arx-eve-link>
          </div>
        </div>
      </div>
    `;
  }
}
