import { getNpub, getUserProfile } from "@/ndk";
import type { NDKUserProfile } from "@nostr-dev-kit/ndk";
import { css, LitElement } from "lit";
import { customElement, state } from "lit/decorators.js";
import { html, literal } from "lit/static-html.js";
import "@widgets/BitcoinBlockWidget";
import "@components/AppGrid";

@customElement("arx-eve-home")
export class Home extends LitElement {
  @state()
  private npub: string | undefined;
  @state()
  private profile: NDKUserProfile | undefined;
  @state()
  private username: string | undefined;

  apps = [
    {
      id: 0,
      href: "letters",
      name: "Letters",
      color: "#FF33BB",
      icon: "bxs:envelope",
    },
    {
      id: 1,
      href: "messages",
      name: "Messages",
      color: "#34C759",
      icon: "bxs:chat",
    },
    {
      id: 2,
      href: "calendar",
      name: "Calendar",
      color: "#FF9500",
      icon: "bxs:calendar",
    },
    {
      id: 3,
      href: "phora",
      name: "Phora",
      color: "#FF3B30",
      icon: "bxs:conversation",
    },
    {
      id: 5,
      href: "agora",
      name: "Agora",
      color: "#5856D6",
      icon: "bxs:store",
    },
    {
      id: 6,
      href: "wallet",
      name: "Wallet",
      color: "#007AFF",
      icon: "bxs:wallet",
    },
    {
      id: 7,
      href: "consortium",
      name: "Consortium",
      color: "#FFCC00",
      icon: "bxs:landmark",
    },
    {
      id: 8,
      href: "settings",
      name: "Settings",
      color: "#deadbeef",
      icon: "bxs:wrench",
    },
  ];

  widgets = [
    {
      title: "Bitcoin Block",
      content: literal`arx-bitcoin-block-widget`,
    },
  ];

  async loadProperties() {
    const npub = await getNpub();
    if (!npub) return alert("No npub?");
    this.npub = npub;
    this.profile = (await getUserProfile(this.npub)) as NDKUserProfile;
    this.username = this.profile?.name || this.npub.substring(0, 8);
  }

  static override styles = [
    css`
      @keyframes gradient {
        0% {
          background-position: 0% 50%;
        }

        50% {
          background-position: 100% 50%;
        }

        100% {
          background-position: 0% 50%;
        }
      }

      .content-wrapper {
        display: flex;
        gap: 20px;
        max-width: 1200px;
        margin: 0 auto;
        padding: 20px;
      }

      .home {
        min-height: calc(100vh - var(--font-2xl));
        width: 100%;
        position: absolute;
        right: 0;
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
      }

      .home-container {
        flex: 1;
        background: rgba(255, 255, 255, 0.5);
        border-radius: 20px;
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
      }

      .widgets-container {
        width: 300px;
        display: flex;
        flex-direction: column;
        gap: 20px;
      }

      .widget {
        background: rgba(255, 255, 255, 0.5);
        border-radius: 15px;
        padding: 20px;
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        backdrop-filter: blur(10px);

        h3 {
          margin: 0 0 10px 0;
          font-size: 18px;
          color: #1c1c1e;
        }

        p {
          margin: 0;
          font-size: 14px;
          color: #333;
          line-height: 1.4;
        }
      }

      @media (max-width: 1024px) {
        .content-wrapper {
          flex-direction: column;
        }

        .widgets-container {
          width: calc(100vw - 40px);
          flex-direction: row;
          overflow-x: auto;
          padding-bottom: 10px;
        }

        .widget {
          min-width: 250px;
        }
      }

      @media (max-width: 768px) {
        .widgets-container {
          flex-direction: column;
        }

        .widget {
          width: auto;
        }
      }

      .welcome-section {
        display: flex;
        flex-direction: column;
        align-items: center;
        justify-content: center;
        gap: 20px;
        padding: 20px;
        background: rgba(255, 255, 255, 0.5);
        border-radius: 20px;
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
      }

      .welcome-text h1 {
        margin: 0;
        font-size: 24px;
        color: #1c1c1e;
      }

      .welcome-text p {
        margin: 5px 0 0;
        color: #666;
        font-size: 14px;
      }
    `,
  ];

  override connectedCallback() {
    super.connectedCallback();
    this.loadProperties();
  }

  override render() {
    return html`
      <div class="home">
        <div class="content-wrapper">
          <div class="home-container">
            <div class="welcome-section">
              <div class="avatar">
                <arx-nostr-profile
                  .npub=${this.npub}
                  render-type="avatar"
                ></arx-nostr-profile>
              </div>
              <div class="welcome-text">
                <h1>Welcome, ${this.username}</h1>
              </div>
            </div>
            <arx-app-grid .apps=${this.apps}></arx-app-grid>
          </div>
          <div class="widgets-container">
            ${this.widgets.map(
              (widget) => html`
                <div class="widget">
                  <h3>${widget.title}</h3>
                  <${widget.content}></${widget.content}>
                </div>
              `
            )}
          </div>
        </div>
      </div>
    `;
  }
}
