import { LitElement, html, css } from "lit";
import { customElement, state } from "lit/decorators.js";
import { getSigner, ndk } from "@/ndk";
import { NDKEvent } from "@nostr-dev-kit/ndk";

@customElement("arx-phora-category-creator")
export class PhoraCategoryCreator extends LitElement {
  @state()
  private newCategory = "";

  @state()
  private categoryDescription = "";

  static override styles = css`
    :host {
      display: block;
    }

    input,
    textarea {
      width: 100%;
      margin-bottom: 1rem;
      padding: 0.5rem;
      border: 1px solid #ccc;
      border-radius: 4px;
    }

    textarea {
      min-height: 100px;
      resize: vertical;
    }
  `;

  private async doCreateCategory() {
    if (this.newCategory.length < 3) {
      alert("Category name must be at least 3 characters long");
      return;
    }

    if (this.categoryDescription.length < 10) {
      alert("Category description must be at least 10 characters long");
      return;
    }

    try {
      await getSigner();
      const event = new NDKEvent(ndk);
      event.kind = 11;
      event.tags = [["subject", this.newCategory]];
      event.content = this.categoryDescription;
      await event.sign();
      await event.publish();

      this.dispatchEvent(
        new CustomEvent("category-created", {
          bubbles: true,
          composed: true,
        })
      );

      this.newCategory = "";
      this.categoryDescription = "";
    } catch (error) {
      console.error("Failed to create category:", error);
      alert("Failed to create category");
    }
  }

  private handleCategoryInput(e: InputEvent) {
    this.newCategory = (e.target as HTMLInputElement).value;
  }

  private handleDescriptionInput(e: InputEvent) {
    this.categoryDescription = (e.target as HTMLTextAreaElement).value;
  }

  override render() {
    return html`
      <input
        type="text"
        placeholder="New Category"
        .value=${this.newCategory}
        @input=${this.handleCategoryInput}
      />

      <textarea
        placeholder="Category Description"
        .value=${this.categoryDescription}
        @input=${this.handleDescriptionInput}
      ></textarea>

      <arx-phora-button @click=${this.doCreateCategory}>
        Create
      </arx-phora-button>
    `;
  }
}
