const MEMPOOL_API = 'https://mempool.space/api/blocks/tip/height';

export interface LastBlockHeight {
  height: number;
  error?: string;
}

export async function getLastBlockHeight(): Promise<LastBlockHeight> {
  try {
    const response = await fetch(MEMPOOL_API);

    if (!response.ok) {
      throw new Error('Network response was not ok');
    }

    const data = await response.text();
    return {
      height: Number.parseInt(data, 10),
    };
  } catch (e) {
    return {
      height: 0,
      error: e instanceof Error ? e.message : 'Failed to fetch block height',
    };
  }
}
